@@ -1,8 +1,6 @@
-from typing import Dict
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel
 
-from otobo_znuny.domain_models.basic_auth_model import BasicAuth
 from otobo_znuny.domain_models.ticket_operation import TicketOperation
 
 type OperationUrlMap = dict[TicketOperation, str]
